@@ -15,7 +15,7 @@ import re
 import warnings
 from collections import defaultdict
 
-from typing import TYPE_CHECKING, Any, Awaitable, Callable, Literal, Sequence
+from typing import TYPE_CHECKING, Any, Callable, Coroutine, Literal, Sequence
 
 from astropy.io import fits
 from astropy.time import Time
@@ -26,6 +26,7 @@ from sdsstools.time import get_sjd
 from gort.exceptions import ErrorCode, GortSpecError
 from gort.tools import (
     cancel_task,
+    decap,
     get_md5sum,
     get_md5sum_from_spectro,
     insert_to_database,
@@ -36,7 +37,7 @@ from gort.tools import (
 
 
 if TYPE_CHECKING:
-    from gort.gort import Gort, GortClient
+    from gort.gort import Gort
 
 
 __all__ = ["Exposure", "READOUT_TIME"]
@@ -45,8 +46,8 @@ __all__ = ["Exposure", "READOUT_TIME"]
 READOUT_TIME = 55
 
 HOOKS_TYPE = defaultdict[
-    Literal["pre-readout", "post-readout"],
-    list[Callable[[Any], Awaitable]],
+    Literal["exposure-starts", "pre-readout", "post-readout"],
+    list[Callable[[Any], Coroutine]],
 ]
 
 
@@ -93,7 +94,7 @@ class Exposure(asyncio.Future["Exposure"]):
 
     def __init__(
         self,
-        gort: Gort | GortClient,
+        gort: Gort,
         exp_no: int | None = None,
         flavour: str | None = "object",
         object: str | None = "",
@@ -117,7 +118,11 @@ class Exposure(asyncio.Future["Exposure"]):
 
         self.hooks: HOOKS_TYPE = defaultdict(
             list,
-            {"pre-readout": [], "post-readout": []},
+            {
+                "exposure-starts": [],
+                "pre-readout": [],
+                "post-readout": [],
+            },
         )
 
         if self.flavour not in ["arc", "object", "flat", "bias", "dark"]:
@@ -238,6 +243,8 @@ class Exposure(asyncio.Future["Exposure"]):
 
             self.start_time = Time.now()
 
+            await self._call_hook("exposure-starts")
+
             await self.specs.send_command_all(
                 "expose",
                 devices=self.devices,
@@ -464,7 +471,8 @@ class Exposure(asyncio.Future["Exposure"]):
             )
         except Exception as err:
             log(
-                f"Error writing to database: {err!r}. Data may not have been recorded.",
+                f"Error writing to database: {decap(err)}. "
+                "Data may not have been recorded.",
                 "warning",
             )
 
@@ -517,7 +525,7 @@ class Exposure(asyncio.Future["Exposure"]):
         if hook_name not in self.hooks:
             raise ValueError(f"Invalid hook {hook_name!r}.")
 
-        self.specs.write_to_log(f"Calling hook {hook_name!r}.")
+        self.specs.write_to_log(f"Calling hook {hook_name!r} functions.")
 
         coros = self.hooks[hook_name]
         if not isinstance(coros, list) and asyncio.iscoroutinefunction(coros):
