@@ -15,41 +15,38 @@ import pathlib
 import subprocess
 import sys
 import uuid
-from copy import deepcopy
+import warnings
+from functools import partial
+from types import TracebackType
 
 from typing import (
     TYPE_CHECKING,
     Any,
-    Callable,
-    ClassVar,
-    Generic,
     Literal,
-    Sequence,
     Type,
     TypeVar,
 )
 
+from lvmopstools.pubsub import send_event
 from lvmopstools.retrier import Retrier
-from packaging.version import Version
 from rich import pretty, traceback
 from rich.logging import RichHandler
 from typing_extensions import Self
 
-from clu.client import AMQPClient, AMQPReply
+from clu.client import AMQPClient
+from clu.exceptions import CluWarning
 from sdsstools.logger import SDSSLogger, get_logger
 from sdsstools.time import get_sjd
 
 from gort import config
-from gort.core import RemoteActor
+from gort.devices.core import GortDevice, GortDeviceSet
 from gort.enums import Event
 from gort.exceptions import ErrorCode, GortError
-from gort.observer import GortObserver
-from gort.pubsub import notify_event
 from gort.recipes import recipes as recipe_to_class
+from gort.remote import RemoteActor
 from gort.tile import Tile
 from gort.tools import (
     get_temporary_file_path,
-    kubernetes_list_deployments,
     kubernetes_restart_deployment,
     overwatcher_is_running,
     run_in_executor,
@@ -73,7 +70,7 @@ except NameError:
     IPYTHON_DEFAULT_HOOKS = []
 
 
-__all__ = ["GortClient", "Gort", "GortDeviceSet", "GortDevice"]
+__all__ = ["GortClient", "Gort"]
 
 
 DevType = TypeVar("DevType", bound="GortDeviceSet | GortDevice")
@@ -96,6 +93,8 @@ class GortClient(AMQPClient):
         The user to connect to the exchange.
     password
         The password to connect to the exchange.
+    verbosity
+        The level of console logging verbosity. One of the standard logging levels.
     use_rich_output
         If :obj:`True`, uses ``rich`` to provide colourised tracebacks and
         prettier outputs.
@@ -113,23 +112,17 @@ class GortClient(AMQPClient):
         port: int = 5672,
         user: str = "guest",
         password: str = "guest",
+        verbosity: str = "INFO",
         use_rich_output: bool = True,
         log_file_path: str | pathlib.Path | Literal[False] | None = None,
     ):
-        from gort.devices.ag import AGSet
-        from gort.devices.enclosure import Enclosure
-        from gort.devices.guider import GuiderSet
-        from gort.devices.nps import NPSSet
-        from gort.devices.spec import SpectrographSet
-        from gort.devices.telemetry import TelemetrySet as TelemSet
-        from gort.devices.telescope import TelescopeSet as TelSet
-
         self.client_uuid = str(uuid.uuid4()).split("-")[0]
 
         self._console: Console
 
         log = self._prepare_logger(
-            log_file_path,
+            log_file_path=log_file_path,
+            verbosity=verbosity,
             use_rich_output=use_rich_output,
         )
 
@@ -146,23 +139,14 @@ class GortClient(AMQPClient):
             log=log,
         )
 
-        self.actors: dict[str, RemoteActor] = {}
-
-        self.config = deepcopy(config)
-
-        self.__device_sets = []
-
-        self.ags = self.add_device(AGSet, self.config["ags"]["devices"])
-        self.guiders = self.add_device(GuiderSet, self.config["guiders"]["devices"])
-        self.telescopes = self.add_device(TelSet, self.config["telescopes"]["devices"])
-        self.nps = self.add_device(NPSSet, self.config["nps"]["devices"])
-        self.specs = self.add_device(SpectrographSet, self.config["specs"]["devices"])
-        self.enclosure = self.add_device(Enclosure, name="enclosure", actor="lvmecp")
-        self.telemetry = self.add_device(TelemSet, self.config["telemetry"]["devices"])
+        # We need to set the verbosity again after the super().__init__() call
+        # because it resets the default log level to WARNING.
+        self.set_verbosity(verbosity)
 
     def _prepare_logger(
         self,
         log_file_path: str | pathlib.Path | Literal[False] | None = None,
+        verbosity: str = "INFO",
         use_rich_output: bool = True,
     ):
         """Creates a logger and start file logging."""
@@ -173,6 +157,8 @@ class GortClient(AMQPClient):
             rich_handler_kwargs={"rich_tracebacks": use_rich_output},
         )
 
+        self.set_verbosity(verbosity, log=log)
+
         if log_file_path is None:
             path = config["logging"]["path"]
             sjd = get_sjd()
@@ -180,8 +166,9 @@ class GortClient(AMQPClient):
 
             try:
                 log.start_file_logger(str(path), rotating=False, mode="a")
-                log.info("Starting GORT.")
-                log.info(f"Logging to {str(path)}")
+                log.debug("Starting GORT.")
+                log.debug(f"Configuration file: {config._CONFIG_FILE or 'N/A'}")
+                log.debug(f"Logging to {str(path)}")
 
             except Exception as err:
                 tmp_path = get_temporary_file_path(
@@ -203,48 +190,115 @@ class GortClient(AMQPClient):
 
         return log
 
-    def _setup_exception_hooks(self, log: SDSSLogger, use_rich_output: bool = True):
+    async def notify_event(self, event: Event, payload: dict[str, Any] = {}):
+        """Emits an event notification."""
+
+        try:
+            await send_event(event, payload=payload)
+        except TypeError as err:
+            if "is not JSON serializable" in str(err):
+                self.log.error(
+                    f"Failed to notify event {event.name}: payload is not"
+                    "serialisable. The event will be emitted without payload."
+                )
+                await send_event(event)
+
+    def exception_handler(
+        self,
+        log: SDSSLogger,
+        exc_type: type[BaseException] | None,
+        exc_value: BaseException | None,
+        exc_traceback: TracebackType | None,
+    ):
+        """A custom exception handler that logs exceptions to file."""
+
+        log.handle_exceptions(exc_type, exc_value, exc_traceback)
+
+        if exc_value and isinstance(exc_value, GortError):
+            event_payload = exc_value.payload.copy()
+            event_payload["error"] = exc_value.args[0] or ""
+            event_payload["error_class"] = exc_type.__name__ if exc_type else "Unknown"
+            event_payload["error_code"] = exc_value.error_code.value
+
+            if exc_type and not getattr(exc_type, "EMIT_EVENT", True):
+                return
+
+            try:
+                loop = asyncio.get_running_loop()
+            except RuntimeError:  # No running event loop, mostly for IPython.
+                log.warning("Cannot emit error event: no running event loop.")
+            else:
+                loop.create_task(self.notify_event(Event.ERROR, payload=event_payload))
+
+    def asyncio_exception_handler(self, loop, context):
+        """Handle an uncaught asyncio exception and reports it."""
+
+        if exception := context.get("exception", None):
+            try:
+                raise exception
+            except Exception:
+                exc_type, exc_value, exc_tb = sys.exc_info()
+                self.exception_handler(self.log, exc_type, exc_value, exc_tb)
+        else:
+            loop.default_exception_handler(context)
+
+    def _setup_exception_hooks(
+        self,
+        log: SDSSLogger | None = None,
+        use_rich_output: bool = True,
+    ):
         """Setup various hooks for exception handling."""
 
+        log = log or self.log
+
         def custom__showtraceback_closure(default__showtraceback):
             def _showtraceback(*args, **kwargs):
                 assert IPYTHON
 
                 exc_tuple = IPYTHON._get_exc_info()
-                log.handle_exceptions(*exc_tuple)
-
-                default__showtraceback(*args, **kwargs)
+                self.exception_handler(log, *exc_tuple)
 
             if IPYTHON:
                 IPYTHON._showtraceback = _showtraceback
 
         if use_rich_output:
-            traceback.install(console=self._console)
-            pretty.install(console=self._console)
+            if not IPYTHON:
+                traceback.install(console=self._console)
+                pretty.install(console=self._console)
 
             # traceback.install() overrides the excepthook, which means that
             # tracebacks are not logged to file anymore. Restore that.
-            sys.excepthook = log.handle_exceptions
+            sys.excepthook = partial(self.exception_handler, log)
 
         else:
             # Make sure we are not using rich tracebacks anymore, in
             # case we installed them at some point.
             # See https://github.com/Textualize/rich/pull/2972/files
 
-            sys.excepthook = log.handle_exceptions
+            sys.excepthook = partial(self.exception_handler, log)
 
             if IPYTHON:
                 IPYTHON._showtraceback = IPYTHON_DEFAULT_HOOKS[0]
                 IPYTHON.showtraceback = IPYTHON_DEFAULT_HOOKS[1]
                 IPYTHON.showsyntaxerror = IPYTHON_DEFAULT_HOOKS[2]
 
-        # if IPYTHON:
-        #     # One more override. We want that any exceptions raised in IPython
-        #     # also gets logged to file, but IPython overrides excepthook completely
-        #     # so here we make a custom call to log.handle_exceptions() and then
-        #     # just let it do whatever it was its default (whether that means it
-        #     # was overridden by rich or not).
-        #     custom__showtraceback_closure(IPYTHON._showtraceback)
+        if IPYTHON:
+            # One more override. We want that any exceptions raised in IPython
+            # also gets logged to file, but IPython overrides excepthook completely
+            # so here we make a custom call to log.handle_exceptions() and then
+            # just let it do whatever it was its default (whether that means it
+            # was overridden by rich or not).
+            custom__showtraceback_closure(IPYTHON._showtraceback)
+
+    def _setup_async_exception_hooks(self):
+        """Sets up a custom async exception handler."""
+
+        try:
+            loop = asyncio.get_running_loop()
+        except RuntimeError:  # No running event loop, mostly for IPython.
+            pass
+        else:
+            loop.set_exception_handler(self.asyncio_exception_handler)
 
     def get_log_path(self):
         """Returns the path of the log file. :obj:`None` if not logging to file."""
@@ -265,8 +319,121 @@ class GortClient(AMQPClient):
             async with self._connect_lock:
                 await self.start()
 
-        override_overwatcher = getattr(self, "_override_overwatcher", None)
+        # Override the asyncio exception handler to catch errors in tasks.
+        # We do this after AMQPClient.start() because it sets its own exception
+        # handler.
+        self._setup_async_exception_hooks()
+
+        return self
+
+    @property
+    def connected(self):
+        """Returns :obj:`True` if the client is connected."""
+
+        return self.connection and self.connection.connection is not None
+
+    def set_verbosity(
+        self,
+        verbosity: str | int | None = None,
+        log: SDSSLogger | None = None,
+    ):
+        """Sets the level of verbosity to ``debug``, ``info``, or ``warning``.
+
+        Parameters
+        ----------
+        verbosity
+            The level of verbosity. Can be a string level name, an integer, or
+            :obj:`None`, in which case the default verbosity will be used.
+        log
+            The logger to set the verbosity for. If :obj:`None`, the internal
+            logger will be used.
+
+        """
+
+        log = log or self.log
+
+        verbosity = verbosity or "warning"
+        if isinstance(verbosity, int):
+            verbosity = logging.getLevelName(verbosity)
+
+        assert isinstance(verbosity, str)
+
+        verbosity = verbosity.lower()
+        if verbosity not in ["debug", "info", "warning"]:
+            raise ValueError("Invalid verbosity value.")
+
+        level_mapping = logging.getLevelNamesMapping()
+        if verbosity_level := level_mapping.get(verbosity.upper()):
+            log.sh.setLevel(verbosity_level)
+
+
+class Gort(GortClient):
+    """Gort's robotic functionality.
+
+    :obj:`.Gort` is subclass of :obj:`.GortClient` that implements higher-level
+    robotic functionality. This is the class a user will normally instantiate and
+    interact with.
+
+    Parameters
+    ----------
+    args, kwargs
+        Arguments to pass to :obj:`.GortClient`.
+    allow_overwatcher
+        If the Overwatcher is running an exception will be raised to prevent
+        GORT running commands that may interfere with it. If ``allow_overwatcher=True``
+        the exception will be suppressed.
+
+    """
+
+    def __init__(
+        self,
+        *args,
+        override_overwatcher: bool | None = None,
+        config_file: str | pathlib.Path | None = None,
+        **kwargs,
+    ):
+        # Not a circular import issue, but here so that importing Gort is a bit faster.
+        from gort.devices.ag import AGSet
+        from gort.devices.enclosure import Enclosure
+        from gort.devices.guider import GuiderSet
+        from gort.devices.nps import NPSSet
+        from gort.devices.spec import SpectrographSet
+        from gort.devices.telemetry import TelemetrySet
+        from gort.devices.telescope import TelescopeSet
+        from gort.observer import GortObserver
+
+        if config_file:
+            config.load(str(config_file))
+
+        super().__init__(*args, **kwargs)
+
+        self.actors: dict[str, RemoteActor] = {}
+
+        self.config = config.copy()
+
+        self.__device_sets = []
+
+        self.ags = self.add_device(AGSet, config["ags.devices"])
+        self.guiders = self.add_device(GuiderSet, config["guiders.devices"])
+        self.telescopes = self.add_device(TelescopeSet, config["telescopes.devices"])
+        self.nps = self.add_device(NPSSet, config["nps.devices"])
+        self.specs = self.add_device(SpectrographSet, config["specs.devices"])
+        self.enclosure = self.add_device(Enclosure, name="enclosure", actor="lvmecp")
+        self.telemetry = self.add_device(TelemetrySet, config["telemetry.devices"])
+
+        self._override_overwatcher = override_overwatcher
+
+        self.observer = GortObserver(self)
+        self.observe_tile = self.observer.observe_tile
+
+    async def init(self) -> Self:
+        """Initialises the client and all devices."""
+
+        await super().init()
+
+        override_overwatcher = self._override_overwatcher
         override_envvar = os.environ.get("GORT_OVERRIDE_OVERWATCHER", "0")
+
         if override_overwatcher is None:
             override_overwatcher = False if override_envvar == "0" else True
 
@@ -284,8 +451,14 @@ class GortClient(AMQPClient):
                         error_code=ErrorCode.OVERATCHER_RUNNING,
                     )
 
+        # Initialise remote actors.
         await asyncio.gather(*[ractor.init() for ractor in self.actors.values()])
 
+        # Monitor the models for all the actors.
+        with warnings.catch_warnings(category=CluWarning):
+            warnings.simplefilter("ignore")
+            await asyncio.gather(*[self.models.add_actor(act) for act in self.actors])
+
         # Initialise device sets.
         await asyncio.gather(*[dev.init() for dev in self.__device_sets])
 
@@ -299,12 +472,6 @@ class GortClient(AMQPClient):
 
         return ds
 
-    @property
-    def connected(self):
-        """Returns :obj:`True` if the client is connected."""
-
-        return self.connection and self.connection.connection is not None
-
     def add_actor(self, actor: str, device: GortDevice | None = None):
         """Adds an actor to the programmatic API.
 
@@ -322,360 +489,6 @@ class GortClient(AMQPClient):
 
         return self.actors[actor]
 
-    def set_verbosity(self, verbosity: str | int | None = None):
-        """Sets the level of verbosity to ``debug``, ``info``, or ``warning``.
-
-        Parameters
-        ----------
-        verbosity
-            The level of verbosity. Can be a string level name, an integer, or
-            :obj:`None`, in which case the default verbosity will be used.
-
-        """
-
-        verbosity = verbosity or "warning"
-        if isinstance(verbosity, int):
-            verbosity = logging.getLevelName(verbosity)
-
-        assert isinstance(verbosity, str)
-
-        verbosity = verbosity.lower()
-        if verbosity not in ["debug", "info", "warning"]:
-            raise ValueError("Invalid verbosity value.")
-
-        verbosity_level = logging.getLevelName(verbosity.upper())
-        self.log.sh.setLevel(verbosity_level)
-
-
-GortDeviceType = TypeVar("GortDeviceType", bound="GortDevice")
-
-
-class GortDeviceSet(dict[str, GortDeviceType], Generic[GortDeviceType]):
-    """A set to gort-managed devices.
-
-    Devices can be accessed as items of the :obj:`.GortDeviceSet` dictionary
-    or using dot notation, as attributes.
-
-    Parameters
-    ----------
-    gort
-        The :obj:`.GortClient` instance.
-    data
-        A mapping of device to device info. Each device must at least include
-        an ``actor`` key with the actor to use to communicated with the device.
-        Any other information is passed to the :obj:`.GortDevice` on instantiation.
-    kwargs
-        Other keyword arguments to pass wo the device class.
-
-    """
-
-    __DEVICE_CLASS__: ClassVar[Type["GortDevice"]]
-    __DEPLOYMENTS__: ClassVar[list[str]] = []
-
-    def __init__(self, gort: GortClient, data: dict[str, dict], **kwargs):
-        self.gort = gort
-
-        _dict_data = {}
-        for device_name in data:
-            device_data = data[device_name].copy()
-            actor_name = device_data.pop("actor")
-            _dict_data[device_name] = self.__DEVICE_CLASS__(
-                gort,
-                device_name,
-                actor_name,
-                **device_data,
-                **kwargs,
-            )
-
-        dict.__init__(self, _dict_data)
-
-    async def init(self):
-        """Runs asynchronous tasks that must be executed on init."""
-
-        # Run devices init methods.
-        results = await asyncio.gather(
-            *[dev.init() for dev in self.values()],
-            return_exceptions=True,
-        )
-
-        for idev, result in enumerate(results):
-            if isinstance(result, Exception):
-                self.write_to_log(
-                    f"Failed initialising device {list(self)[idev]} "
-                    f"with error {str(result)}",
-                    "error",
-                )
-
-        return
-
-    def __getattribute__(self, __name: str) -> Any:
-        if __name in self:
-            return self.__getitem__(__name)
-        return super().__getattribute__(__name)
-
-    async def call_device_method(self, method: Callable, *args, **kwargs):
-        """Calls a method in each one of the devices.
-
-        Parameters
-        ----------
-        method
-            The method to call. This must be the abstract class method,
-            not the method from an instantiated object.
-        args,kwargs
-            Arguments to pass to the method.
-
-        """
-
-        if not callable(method):
-            raise GortError("Method is not callable.")
-
-        if hasattr(method, "__self__"):
-            # This is a bound method, so let's get the class method.
-            method = method.__func__
-
-        if not hasattr(self.__DEVICE_CLASS__, method.__name__):
-            raise GortError("Method does not belong to this class devices.")
-
-        devices = self.values()
-
-        return await asyncio.gather(*[method(dev, *args, **kwargs) for dev in devices])
-
-    async def send_command_all(
-        self,
-        command: str,
-        *args,
-        devices: Sequence[str] | None = None,
-        **kwargs,
-    ):
-        """Sends a command to all the devices.
-
-        Parameters
-        ----------
-        command
-            The command to call.
-        args, kwargs
-            Arguments to pass to the :obj:`.RemoteCommand`.
-
-        """
-
-        tasks = []
-        for name, dev in self.items():
-            if devices is not None and name not in devices:
-                continue
-
-            actor_command = dev.actor.commands[command]
-            tasks.append(actor_command(*args, **kwargs))
-
-        return await asyncio.gather(*tasks)
-
-    def write_to_log(
-        self,
-        message: str,
-        level: str = "debug",
-        header: str | None = None,
-    ):
-        """Writes a message to the log with a custom header.
-
-        Parameters
-        ----------
-        message
-            The message to log.
-        level
-            The level to use for logging: ``'debug'``, ``'info'``, ``'warning'``, or
-            ``'error'``.
-        header
-            The header to prepend to the message. By default uses the class name.
-
-        """
-
-        if header is None:
-            header = f"({self.__class__.__name__}) "
-
-        message = f"{header}{message}"
-
-        level = logging.getLevelName(level.upper())
-        assert isinstance(level, int)
-
-        self.gort.log.log(level, message)
-
-    async def restart(self):
-        """Restarts the set deployments and resets all controllers.
-
-        Returns
-        -------
-        result
-            A boolean indicting if the entire restart procedure succeeded.
-
-        """
-
-        failed: bool = False
-
-        self.write_to_log("Restarting Kubernetes deployments.", "info")
-        for deployment in self.__DEPLOYMENTS__:
-            await kubernetes_restart_deployment(deployment)
-
-        self.write_to_log("Waiting 15 seconds for deployments to be ready.", "info")
-        await asyncio.sleep(15)
-
-        # Check that deployments are running.
-        running_deployments = await kubernetes_list_deployments()
-        for deployment in self.__DEPLOYMENTS__:
-            if deployment not in running_deployments:
-                failed = True
-                self.write_to_log(f"Deployment {deployment} did not restart.", "error")
-
-        # Refresh the command models for all the actors.
-        await asyncio.gather(*[actor.refresh() for actor in self.gort.actors.values()])
-
-        # Refresh the device set.
-        await self.init()
-
-        return not failed
-
-
-class GortDevice:
-    """A gort-managed device.
-
-    Parameters
-    ----------
-    gort
-        The :obj:`.GortClient` instance.
-    name
-        The name of the device.
-    actor
-        The name of the actor used to interface with this device. The actor is
-        added to the list of :obj:`.RemoteActor` in the :obj:`.GortClient`.
-
-
-    """
-
-    def __init__(self, gort: GortClient, name: str, actor: str):
-        self.gort = gort
-        self.name = name
-        self.actor = gort.add_actor(actor, device=self)
-
-        # Placeholder version. The real one is retrieved on init.
-        self.version = Version("0.99.0")
-
-    async def init(self):
-        """Runs asynchronous tasks that must be executed on init.
-
-        If the device is part of a :obj:`.DeviceSet`, this method is called
-        by :obj:`.DeviceSet.init`.
-
-        """
-
-        # Get the version of the actor.
-        if "version" in self.actor.commands:
-            try:
-                reply = await self.actor.commands.version()
-                if (version := reply.get("version")) is not None:
-                    self.version = Version(version)
-            except Exception:
-                pass
-
-        return
-
-    def write_to_log(
-        self,
-        message: str,
-        level: str = "debug",
-        header: str | None = None,
-    ):
-        """Writes a message to the log with a custom header.
-
-        Parameters
-        ----------
-        message
-            The message to log.
-        level
-            The level to use for logging: ``'debug'``, ``'info'``, ``'warning'``, or
-            ``'error'``.
-        header
-            The header to prepend to the message. By default uses the device name.
-
-        """
-
-        if header is None:
-            header = f"({self.name}) "
-
-        message = f"{header}{message}"
-
-        level = logging.getLevelName(level.upper())
-        assert isinstance(level, int)
-
-        self.gort.log.log(level, message)
-
-    def log_replies(self, reply: AMQPReply, skip_debug: bool = True):
-        """Outputs command replies."""
-
-        if reply.body:
-            if reply.message_code in ["w"]:
-                level = "warning"
-            elif reply.message_code in ["e", "f", "!"]:
-                level = "error"
-            else:
-                level = "debug"
-                if skip_debug:
-                    return
-
-            self.write_to_log(str(reply.body), level)
-
-
-class Gort(GortClient):
-    """Gort's robotic functionality.
-
-    :obj:`.Gort` is subclass of :obj:`.GortClient` that implements higher-level
-    robotic functionality. This is the class a user will normally instantiate and
-    interact with.
-
-    Parameters
-    ----------
-    args, kwargs
-        Arguments to pass to :obj:`.GortClient`.
-    allow_overwatcher
-        If the Overwatcher is running an exception will be raised to prevent
-        GORT running commands that may interfere with it. If ``allow_overwatcher=True``
-        the exception will be suppressed.
-    verbosity
-        The level of logging verbosity.
-
-    """
-
-    def __init__(
-        self,
-        *args,
-        override_overwatcher: bool | None = None,
-        verbosity: str | None = None,
-        config_file: str | pathlib.Path | None = None,
-        **kwargs,
-    ):
-        if config_file:
-            config.load(str(config_file))
-
-        super().__init__(*args, **kwargs)
-
-        self._override_overwatcher = override_overwatcher
-
-        self.observer = GortObserver(self)
-        self.observe_tile = self.observer.observe_tile
-
-        if verbosity:
-            self.set_verbosity(verbosity)
-
-    async def notify_event(self, event: Event, payload: dict[str, Any] = {}):
-        """Emits an event notification."""
-
-        try:
-            await notify_event(event, payload=payload)
-        except TypeError as err:
-            if "is not JSON serializable" in str(err):
-                self.log.error(
-                    f"Failed to notify event {event.name}: payload is not"
-                    "serialisable. The event will be emitted without payload."
-                )
-                await notify_event(event)
-
     @Retrier(max_attempts=3, delay=3)
     async def emergency_shutdown(self):
         """Parks and closes the telescopes."""
@@ -687,18 +500,18 @@ class Gort(GortClient):
             await self.shutdown(
                 park_telescopes=True,
                 disable_overwatcher=True,
-                retry_without_parking=True,
                 show_message=False,
             )
 
-        except Exception as err:
-            self.log.error(f"Failed to shutdown: {err!r}")
-            self.log.warning("Trying to just close the dome.")
-
+        except Exception:
+            self.log.error(
+                "The normal shutdown failed. Trying to "
+                "close the dome in overcurrent mode."
+            )
             await self.enclosure.close(
-                park_telescopes=True,
+                park_telescopes=False,
                 force=True,
-                retry_without_parking=True,
+                mode="overcurrent",
             )
 
     async def observe(
@@ -767,10 +580,9 @@ class Gort(GortClient):
                         )
                         continue
 
-                    await set_tile_status(tile_id, enabled=False)
+                    await set_tile_status(tile_id, note="Acquisition failed")
                     self.log.warning(
-                        f"tile_id={tile_id} has been disabled. "
-                        "Continuing observations."
+                        f"tile_id={tile_id} has been disabled. Continuing observations."
                     )
 
                 elif ee.error_code == ErrorCode.SCHEDULER_CANNOT_FIND_TILE:
