@@ -10,12 +10,13 @@
 from __future__ import annotations
 
 from .alerts import AlertsOverwatcher
-from .calibration import CalibrationsOverwatcher
+from .calibrations import CalibrationsOverwatcher
 from .core import OverwatcherModule
 from .ephemeris import EphemerisOverwatcher
 from .events import EventsOverwatcher
+from .health import HealthOverwatcher
 from .helpers import DomeHelper, DomeStatus, NotifierMixIn
 from .observer import ObserverOverwatcher
 from .overwatcher import Overwatcher
 from .safety import SafetyOverwatcher
-from .weather import WeatherOverwatcher
+from .transparency import TransparencyOverwatcher
