@@ -38,6 +38,7 @@ class OverwatcherState:
 
     running: bool = False
     enabled: bool = False
+    idle: bool = True
     observing: bool = False
     calibrating: bool = False
     troubleshooting: bool = False
@@ -88,7 +89,7 @@ class OverwatcherMainTask(OverwatcherTask):
             try:
                 ow.state.night = ow.ephemeris.is_night()
 
-                ow.state.safe, alerts_bits = ow.alerts.is_safe()
+                ow.state.safe, alerts_bits = await ow.alerts.is_safe()
                 ow.state.alerts = [
                     alert.name
                     for alert in ActiveAlert
@@ -101,6 +102,14 @@ class OverwatcherMainTask(OverwatcherTask):
 
                 ow.state.troubleshooting = ow.is_troubleshooting()
 
+                ow.state.idle = await ow.dome.is_opening() and not (
+                    ow.state.observing
+                    or ow.state.calibrating
+                    or ow.state.focusing
+                    or ow.state.troubleshooting
+                    or ow.observer._starting_observations
+                )
+
                 # TODO: should these handlers be scheduled as tasks? Right now
                 # they can block for a good while until the dome is open/closed.
 
@@ -156,7 +165,7 @@ class OverwatcherMainTask(OverwatcherTask):
         observing = ow.observer.is_observing
         calibrating = ow.calibrations.is_calibrating()
 
-        _, alerts_status = ow.alerts.is_safe()
+        _, alerts_status = await ow.alerts.is_safe()
 
         # If the only alert is that the dome is locked there is not much we
         # can do, so we just continue ...
@@ -206,11 +215,18 @@ class OverwatcherMainTask(OverwatcherTask):
                 else "UNKNOWN"
             )
 
-            await ow.shutdown(
-                reason=f"Unsafe conditions detected: {alert_names}",
-                close_dome=close_dome,
-                disable_overwatcher=disable_overwatcher,
-            )
+            try:
+                await ow.shutdown(
+                    reason=f"Unsafe conditions detected: {alert_names}",
+                    close_dome=close_dome,
+                    disable_overwatcher=disable_overwatcher,
+                )
+            except Exception as err:
+                await ow.notify(
+                    f"Error executing the shutdown procedure: {decap(err)}",
+                    level="critical",
+                    error=err,
+                )
 
     async def handle_daytime(self):
         """Handles daytime conditions."""
@@ -457,6 +473,7 @@ class Overwatcher(NotifierMixIn):
 
         dome_closed = await self.dome.is_closing()
         dome_locked = self.dome.locked
+        local_mode = await self.gort.enclosure.is_local()
 
         calibrating = self.calibrations.is_calibrating()
 
@@ -489,7 +506,7 @@ class Overwatcher(NotifierMixIn):
         try:
             stop_observing = self.observer.stop_observing(
                 immediate=True,
-                reason=reason or "shutdown triggered",
+                reason="shutdown triggered",
             )
 
             self.log.info("Cancelling observing loop and calibrations.")
@@ -520,26 +537,44 @@ class Overwatcher(NotifierMixIn):
 
         # Step 3: close the dome.
         if close_dome and not dome_closed and not dome_locked:
-            try:
-                await asyncio.wait_for(
-                    self.dome.close(retry=retry, park=park),
-                    timeout=360,
-                )
-            except Exception as err:
-                # Check if the dome is closed to determine
-                # the level of the notification.
-                level = "warning" if await self.dome.is_closed() else "critical"
-
+            if local_mode:
                 await self.notify(
-                    f"Error closing the dome during shutdown: {decap(err)}",
-                    level=level,
-                    error=err,
+                    "Enclosure is in local mode. Dome will not be closed.",
+                    min_time_between_repeat_notifications=600,
+                    level="warning",
                 )
                 return
+            else:
+                try:
+                    await asyncio.wait_for(
+                        self.dome.close(retry=retry, park=park),
+                        timeout=360,
+                    )
+                except Exception as err:
+                    # Check if the dome is closed to determine
+                    # the level of the notification.
+                    level = "warning" if await self.dome.is_closed() else "critical"
+
+                    await self.notify(
+                        f"Error closing the dome during shutdown: {decap(err)}",
+                        level=level,
+                        error=err,
+                    )
+                    return
 
         # Step 4: park and disable the telescopes.
-        if park:
-            await asyncio.wait_for(self.gort.telescopes.park(disable=True), timeout=120)
+        if park and not local_mode:
+            try:
+                await asyncio.wait_for(
+                    self.gort.telescopes.park(disable=True),
+                    timeout=120,
+                )
+            except Exception as err:
+                await self.notify(
+                    f"Error parking the telescopes during shutdown: {decap(err)}",
+                    level="error",
+                    error=err,
+                )
 
         # Acknowledge any pending shutdown.
         self.state.shutdown_pending = False
