@@ -137,8 +137,9 @@ class AcquisitionFailedRecipe(TroubleshooterRecipe):
         pings = await self.ping_ag_cameras()
         if all(pings.values()):
             if await self.all_cameras_alive():
-                await self.notify("All AG cameras are up and pinging.")
-                return True
+                # Return false because we don't know why the acquisition failed.
+                # This will cause the tile to be disabled.
+                return False
 
             await self.notify(
                 "All AG cameras ping but some are not responding status. "
@@ -180,10 +181,15 @@ class AcquisitionFailedRecipe(TroubleshooterRecipe):
         )
 
         # Use the API since it already includes all the logic.
-        await run_lvmapi_task(
-            "/macros/power_cycle_ag_cameras",
-            params={"cameras": failed_cameras},
-        )
+        try:
+            await run_lvmapi_task(
+                "/macros/power_cycle_ag_cameras",
+                params={"cameras": failed_cameras},
+                timeout=300,
+            )
+        except asyncio.TimeoutError:
+            raise TroubleshooterCriticalError("Power cycling AG cameras timed out.")
+
         await asyncio.sleep(30)
 
         # Check pings again. If they are not yet pinging, we have a problem.
