@@ -9,6 +9,7 @@
 from __future__ import annotations
 
 import asyncio
+import json
 
 from typing import TYPE_CHECKING, ClassVar, Coroutine
 
@@ -185,9 +186,11 @@ class ShutdownRecipe(BaseRecipe):
             self.gort.log.info("Disabling the overwatcher.")
             tasks.append(self.gort.send_command("lvm.overwatcher", "disable --now"))
 
-        for result in await asyncio.gather(*tasks, return_exceptions=True):
-            if isinstance(result, Exception):
-                self.gort.log.error(f"Error during shutdown: {decap(result)}")
+        for task in tasks:
+            try:
+                await task
+            except Exception as err:
+                self.gort.log.error(f"Error during shutdown: {decap(err)}")
                 errored = True
 
         if park_telescopes:
@@ -279,6 +282,8 @@ class CleanupRecipe(BaseRecipe):
             self.gort.enclosure.lights.telescope_bright.off(),
         )
 
+        self.gort.log.info("Cleanup recipe has completed.")
+
     async def _wait_until_spec_is_idle(self, spec: Spectrograph):
         """Waits until an spectrograph is idle."""
 
@@ -345,6 +350,11 @@ class PreObservingRecipe(BaseRecipe):
         # Create the night log if it doesn't exist.
         await get_lvmapi_route("/logs/night-logs/create")
 
+        # Dump the current configuration to the log so that we know what we
+        # were using at the start of the night.
+        self.gort.log.info("Dumping current configuration to the log.")
+        self.gort.log.info(json.dumps(dict(self.gort.config), indent=2))
+
 
 class PostObservingRecipe(BaseRecipe):
     """Runs the post-observing tasks.
