@@ -12,6 +12,7 @@ import warnings
 
 from typing import Sequence, cast
 
+import numpy
 import polars
 from astropy.coordinates import EarthLocation, SkyCoord
 from astropy.time import Time
@@ -259,6 +260,31 @@ class ScienceCoordinates(Coordinates):
 
     dither_position: int = 0
 
+    def get_dither_radec(self):
+        """Returns the dithered RA/Dec coordinates."""
+
+        if self.dither_position is None:
+            return self.ra, self.dec
+
+        # Get dither position offsets
+        dither = self.dither_position
+        raoff, decoff = config["guiders"]["devices"]["sci"]["dither_offsets"][dither]
+
+        # Rotate by the PA.
+        pa_rad = numpy.radians(self.pa)
+        rot_m = numpy.array(
+            [
+                [numpy.cos(-pa_rad), -numpy.sin(-pa_rad)],
+                [numpy.sin(-pa_rad), numpy.cos(-pa_rad)],
+            ]
+        )
+        raoff, decoff = numpy.dot(rot_m, [raoff, decoff])
+
+        ra = self.ra - raoff / 3600 / numpy.cos(numpy.radians(self.dec))
+        dec = self.dec - decoff / 3600
+
+        return ra, dec
+
 
 class SkyCoordinates(QuerableCoordinates):
     """A sky position.
