@@ -13,6 +13,7 @@ import concurrent.futures
 import datetime
 import functools
 import hashlib
+import logging
 import os
 import pathlib
 import re
@@ -25,10 +26,13 @@ from typing import (
     TYPE_CHECKING,
     Any,
     AsyncGenerator,
+    Awaitable,
     Callable,
     Coroutine,
     Generator,
+    Literal,
     Sequence,
+    TypeVar,
 )
 
 import httpx
@@ -51,7 +55,7 @@ if TYPE_CHECKING:
     from clu import AMQPClient, AMQPReply
 
     from gort.devices.telescope import FibSel
-    from gort.gort import GortClient
+    from gort.gort import Gort
 
 
 __all__ = [
@@ -81,6 +85,7 @@ __all__ = [
     "mark_exposure_bad",
     "handle_signals",
     "get_lvmapi_route",
+    "run_lvmapi_task",
     "GuiderMonitor",
     "overwatcher_is_running",
     "get_by_source_id",
@@ -91,6 +96,10 @@ __all__ = [
     "get_gort_client",
     "add_night_log_comment",
     "async_noop",
+    "LogNamespace",
+    "decap",
+    "ensure_period",
+    "try_or_pass",
 ]
 
 AnyPath = str | os.PathLike
@@ -235,18 +244,17 @@ def mark_exposure_bad(tile_id: int, dither_position: int = 0):
     ).execute()
 
 
-async def set_tile_status(tile_id: int, enabled: bool = True):
+async def set_tile_status(tile_id: int, note: str | None = None):
     """Enables/disables a tile in the database."""
 
     sch_config = config["services"]["scheduler"]
     host = sch_config["host"]
     port = sch_config["port"]
 
-    disable = "false" if enabled else "true"
-
     async with httpx.AsyncClient() as client:
         resp = await client.put(
-            f"http://{host}:{port}/tile_status/?tile_id={tile_id}&disable={disable}",
+            f"http://{host}:{port}/tile_status",
+            params={"tile_id": tile_id, "note": note},
             json={},
             follow_redirects=True,
         )
@@ -339,7 +347,7 @@ def get_ccd_frame_path(
 
 
 async def move_mask_interval(
-    gort: GortClient,
+    gort: Gort,
     positions: str | list[str] = "P1-*",
     order_by_steps: bool = False,
     total_time: float | None = None,
@@ -714,29 +722,94 @@ def get_ephemeris_summary_sync(sjd: int | None = None) -> dict:
     return resp.json()
 
 
-async def get_lvmapi_route(route: str, params: dict = {}, **kwargs):
+async def get_lvmapi_route(route: str, params: dict = {}, timeout: float = 5, **kwargs):
     """Gets an ``lvmapi`` route."""
 
     params.update(kwargs)
 
     host, port = config["services"]["lvmapi"].values()
 
-    async with httpx.AsyncClient(
-        base_url=f"http://{host}:{port}",
-        follow_redirects=True,
-    ) as client:
-        response = await client.get(route, params=params)
+    if "/" in host:
+        host, base_route = host.split("/")
+        if base_route != "":
+            base_route += "/"
+    else:
+        base_route = ""
 
-        if response.status_code != 200:
-            raise ValueError(f"Route {route} failed with error {response.status_code}.")
+    if route.startswith("/"):
+        route = route[1:]
+
+    if "?" in route:
+        raise ValueError("Query parameters should be passed as a dictionary.")
+
+    async with httpx.AsyncClient(
+        base_url=f"http://{host}:{port}/{base_route}",
+        follow_redirects=True,
+        timeout=timeout,
+    ) as client:
+        response = await client.get(route, params=params, timeout=timeout)
+
+        if (code := response.status_code) != 200:
+            raise ValueError(f"Route /{route} failed with error {code}.")
 
     return response.json()
 
 
+async def run_lvmapi_task(
+    route: str,
+    params: dict = {},
+    wait: bool = True,
+    check_interval: float = 3,
+    timeout: float | None = None,
+    **kwargs,
+):
+    """Runs an LVM API task route.
+
+    Task routes immediately start the task in the background and return a task ID.
+    The API can then be queried until the task is completed.
+
+    Parameters
+    ----------
+    route
+        The route to the task.
+    params
+        The parameters to pass to the route.
+    wait
+        If :obj:`True`, waits until the task is completed and returns the result.
+    check_interval
+        The interval at which to check the task status. Ignored if ``wait=False``.
+    timeout
+        The timeout for the task execution. Ignored if ``wait=False``.
+
+    Returns
+    -------
+    result
+        The task ID if ``wait=False`` or the result of the task if ``wait=True``.
+
+    """
+
+    task_id = await get_lvmapi_route(route, params=params, **kwargs)
+
+    if not wait:
+        return task_id
+
+    elapsed: float = 0
+    while True:
+        await asyncio.sleep(check_interval)
+        elapsed += check_interval
+
+        ready = await get_lvmapi_route(f"/tasks/{task_id}/ready", timeout=10)
+        if ready is True:
+            return await get_lvmapi_route(f"/tasks/{task_id}/result", timeout=10)
+
+        if timeout and elapsed > timeout:
+            raise asyncio.TimeoutError(f"Task {task_id} did not complete in time.")
+
+
 class GuiderMonitor:
     """A tool to monitor guider outputs and store them in a dataframe."""
 
-    def __init__(self, gort: GortClient, actor: str | None = None):
+    def __init__(self, gort: Gort, actor: str | None = None):
         self.gort = gort
         self.actor = actor
 
@@ -1007,7 +1080,10 @@ async def get_gort_client(override_overwatcher: bool | None = None):
     await gort.stop()
 
 
-async def add_night_log_comment(comment: str, category: str = "other"):
+NightLogCategories = Literal["weather", "issues", "other", "observers", "overwatcher"]
+
+
+async def add_night_log_comment(comment: str, category: NightLogCategories = "other"):
     """Adds a comment to the night log."""
 
     payload = {
@@ -1022,7 +1098,7 @@ async def add_night_log_comment(comment: str, category: str = "other"):
         base_url=f"http://{host}:{port}",
         follow_redirects=True,
     ) as client:
-        response = await client.post("/night-logs/comments/add", json=payload)
+        response = await client.post("/logs/night-logs/comments/add", json=payload)
 
         code = response.status_code
         if code != 200:
@@ -1033,3 +1109,70 @@ async def async_noop(*args, **kwargs):
     """A no-op coroutine."""
 
     return None
+
+
+class LogNamespace:
+    """A namespace for log messages."""
+
+    def __init__(self, logger: logging.Logger, header: str = "") -> None:
+        self.logger = logger
+        self.header = header
+
+    def debug(self, message: str, *args, **kwargs):
+        self.logger.log(logging.DEBUG, self._get_message(message), *args, **kwargs)
+
+    def info(self, message: str, *args, **kwargs):
+        self.logger.log(logging.INFO, self._get_message(message), *args, **kwargs)
+
+    def warning(self, message: str, *args, **kwargs):
+        self.logger.log(logging.WARNING, self._get_message(message), *args, **kwargs)
+
+    def error(self, message: str, *args, **kwargs):
+        self.logger.log(logging.ERROR, self._get_message(message), *args, **kwargs)
+
+    def critical(self, message: str, *args, **kwargs):
+        self.logger.log(logging.CRITICAL, self._get_message(message), *args, **kwargs)
+
+    def exception(self, *args, **kwargs):
+        self.logger.exception(*args, **kwargs)
+
+    def _get_message(self, message: str):
+        return self.header.format(**locals()) + message
+
+
+def decap(string: Any, add_period: bool = False):
+    """Decapitalises the first letter of a string."""
+
+    if not isinstance(string, str):
+        string = str(string)
+
+    if len(string) == 0:
+        return ""
+
+    decapped = str(string[0].lower() + string[1:])
+
+    if not add_period:
+        return decapped
+
+    return ensure_period(decapped)
+
+
+def ensure_period(string: str):
+    """Ensures that a string ends with a period."""
+
+    if not string.strip().endswith("."):
+        string += "."
+
+    return string
+
+
+T = TypeVar("T", bound=Any)
+
+
+async def try_or_pass(coro: Awaitable[T]) -> T | None:
+    """Decorator that wraps a coroutine in a try/except block."""
+
+    try:
+        return await coro
+    except Exception:
+        pass
